pydatajson package
==================

Submodules
----------

pydatajson.ckan_reader module
-----------------------------

.. automodule:: pydatajson.ckan_reader
    :members:
    :undoc-members:
    :show-inheritance:

pydatajson.ckan_utils module
----------------------------

.. automodule:: pydatajson.ckan_utils
    :members:
    :undoc-members:
    :show-inheritance:

pydatajson.core module
----------------------

.. automodule:: pydatajson.core
    :members:
    :undoc-members:
    :show-inheritance:

pydatajson.custom_exceptions module
-----------------------------------

.. automodule:: pydatajson.custom_exceptions
    :members:
    :undoc-members:
    :show-inheritance:

pydatajson.documentation module
-------------------------------

.. automodule:: pydatajson.documentation
    :members:
    :undoc-members:
    :show-inheritance:

pydatajson.download module
--------------------------

.. automodule:: pydatajson.download
    :members:
    :undoc-members:
    :show-inheritance:

pydatajson.federation module
----------------------------

.. automodule:: pydatajson.federation
    :members:
    :undoc-members:
    :show-inheritance:

pydatajson.helpers module
-------------------------

.. automodule:: pydatajson.helpers
    :members:
    :undoc-members:
    :show-inheritance:

pydatajson.indicators module
----------------------------

.. automodule:: pydatajson.indicators
    :members:
    :undoc-members:
    :show-inheritance:

pydatajson.readers module
-------------------------

.. automodule:: pydatajson.readers
    :members:
    :undoc-members:
    :show-inheritance:

pydatajson.reporting module
---------------------------

.. automodule:: pydatajson.reporting
    :members:
    :undoc-members:
    :show-inheritance:

pydatajson.search module
------------------------

.. automodule:: pydatajson.search
    :members:
    :undoc-members:
    :show-inheritance:

pydatajson.time_series module
-----------------------------

.. automodule:: pydatajson.time_series
    :members:
    :undoc-members:
    :show-inheritance:

pydatajson.validation module
----------------------------

.. automodule:: pydatajson.validation
    :members:
    :undoc-members:
    :show-inheritance:

pydatajson.writers module
-------------------------

.. automodule:: pydatajson.writers
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: pydatajson
    :members:
    :undoc-members:
    :show-inheritance:
